# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: health.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0chealth.proto\x12\x0egrpc.health.v1\"%\n\x12HealthCheckRequest\x12\x0f\n\x07service\x18\x01 \x01(\t\"\xa9\x01\n\x13HealthCheckResponse\x12\x41\n\x06status\x18\x01 \x01(\x0e\x32\x31.grpc.health.v1.HealthCheckResponse.ServingStatus\"O\n\rServingStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SERVING\x10\x01\x12\x0f\n\x0bNOT_SERVING\x10\x02\x12\x13\n\x0fSERVICE_UNKNOWN\x10\x03\x32\xae\x01\n\x06Health\x12P\n\x05\x43heck\x12\".grpc.health.v1.HealthCheckRequest\x1a#.grpc.health.v1.HealthCheckResponse\x12R\n\x05Watch\x12\".grpc.health.v1.HealthCheckRequest\x1a#.grpc.health.v1.HealthCheckResponse0\x01\x42#Z!github.com/lugobots/lugo4go/protob\x06proto3')



_HEALTHCHECKREQUEST = DESCRIPTOR.message_types_by_name['HealthCheckRequest']
_HEALTHCHECKRESPONSE = DESCRIPTOR.message_types_by_name['HealthCheckResponse']
_HEALTHCHECKRESPONSE_SERVINGSTATUS = _HEALTHCHECKRESPONSE.enum_types_by_name['ServingStatus']
HealthCheckRequest = _reflection.GeneratedProtocolMessageType('HealthCheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKREQUEST,
  '__module__' : 'health_pb2'
  # @@protoc_insertion_point(class_scope:grpc.health.v1.HealthCheckRequest)
  })
_sym_db.RegisterMessage(HealthCheckRequest)

HealthCheckResponse = _reflection.GeneratedProtocolMessageType('HealthCheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKRESPONSE,
  '__module__' : 'health_pb2'
  # @@protoc_insertion_point(class_scope:grpc.health.v1.HealthCheckResponse)
  })
_sym_db.RegisterMessage(HealthCheckResponse)

_HEALTH = DESCRIPTOR.services_by_name['Health']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z!github.com/lugobots/lugo4go/proto'
  _HEALTHCHECKREQUEST._serialized_start=32
  _HEALTHCHECKREQUEST._serialized_end=69
  _HEALTHCHECKRESPONSE._serialized_start=72
  _HEALTHCHECKRESPONSE._serialized_end=241
  _HEALTHCHECKRESPONSE_SERVINGSTATUS._serialized_start=162
  _HEALTHCHECKRESPONSE_SERVINGSTATUS._serialized_end=241
  _HEALTH._serialized_start=244
  _HEALTH._serialized_end=418
# @@protoc_insertion_point(module_scope)



from ..src import lugo, snapshot
from ..mapper import Mapper
from abc import ABC, abstractmethod


class PlayerState(object):
    SUPPORTING = 0
    HOLDING_THE_BALL = 1
    DEFENDING = 2
    DISPUTING_THE_BALL = 3


PLAYER_STATE = PlayerState()


class Bot(ABC):
    def __init__(self, side: lugo.TeamSide, number: int, init_position: lugo.Point, my_mapper: Mapper):
        self.number = number
        self.side = side
        self.mapper = my_mapper
        self.initPosition = init_position

    @abstractmethod
    def on_disputing(self, order_set: lugo.OrderSet, game_snapshot: lugo.GameSnapshot) -> lugo.OrderSet:
        pass

    @abstractmethod
    def on_defending(self, order_set: lugo.OrderSet, game_snapshot: lugo.GameSnapshot) -> lugo.OrderSet:
        pass

    @abstractmethod
    def on_holding(self, order_set: lugo.OrderSet, game_snapshot: lugo.GameSnapshot) -> lugo.OrderSet:
        pass

    @abstractmethod
    def on_supporting(self, order_set: lugo.OrderSet, game_snapshot: lugo.GameSnapshot) -> lugo.OrderSet:
        pass

    @abstractmethod
    def as_goalkeeper(self, order_set: lugo.OrderSet, game_snapshot: lugo.GameSnapshot, state: PLAYER_STATE) -> lugo.OrderSet:
        pass

    @abstractmethod
    def getting_ready(self, game_snapshot: lugo.GameSnapshot):
        pass

    def make_reader(self, game_snapshot: lugo.GameSnapshot):
        reader = snapshot.GameSnapshotReader(game_snapshot, self.side)
        me = reader.get_player(self.side, self.number)
        if me is None:
            raise AttributeError("did not find myself in the game")

        return reader, me
